@@ -31,12 +31,8 @@
  */
 
 #if (HAVE_CONFIG_H)
-#if ((_WIN32) && !(__CYGWIN__)) 
-#include "../include/win32/config.h"
-#else
 #include "../include/config.h"
 #endif
-#endif
 #include "./libnet_test.h"
 
 int
@@ -133,4 +129,3 @@ bad:
     return (EXIT_FAILURE);
 }
 
-/* EOF */
