@@ -95,7 +95,7 @@
                                                                                \
     if (ptr && !size)                                                          \
     {                                                                          \
-	size = strlen(ptr);                                                    \
+	size = strlen((char *)ptr);                                            \
     }                                                                          
 
 
@@ -149,7 +149,7 @@ main(int argc, char *argv[])
             /*
              *  We expect the input to be of the form `ip.ip.ip.ip.port`.  We
              *  point cp to the last dot of the IP address/port string and
-             *  then seperate them with a NULL byte.  The optarg now points to
+             *  then separate them with a NULL byte.  The optarg now points to
              *  just the IP address, and cp points to the port.
              */
             case 'd':
@@ -169,12 +169,12 @@ main(int argc, char *argv[])
                 break;
 
 	    case 'p':
-		payload = optarg;
-		payload_s = strlen(payload);
+		payload = (u_char *)optarg;
+		payload_s = strlen((char *)payload);
 		break;
 
 	    case 'w':
-		withdraw_rt = optarg;
+		withdraw_rt = (u_char *)optarg;
 		break;
 
 	    case 'W':
@@ -182,7 +182,7 @@ main(int argc, char *argv[])
 		break;
 
 	    case 'a':
-		attr = optarg;
+		attr = (u_char *)optarg;
 		break;
 
 	    case 'A':
@@ -190,7 +190,7 @@ main(int argc, char *argv[])
 		break;
 
 	    case 'i':
-		info = optarg;
+		info = (u_char *)optarg;
 		break;
 
 	    case 'I':
@@ -334,4 +334,3 @@ usage(char *name)
 }
 
 
-/* EOF */
