@@ -35,12 +35,8 @@
  */
 
 #if (HAVE_CONFIG_H)
-#if ((_WIN32) && !(__CYGWIN__)) 
-#include "../include/win32/config.h"
-#else
 #include "../include/config.h"
 #endif
-#endif
 #include "./libnet_test.h"
 
 
@@ -86,7 +82,7 @@ main(int argc, char *argv[])
     index += 5;
 
     /* this TLV is handled by the libnet builder */
-    value = argv[2];
+    value = (u_char *)argv[2];
     len = strlen(argv[2]);
 
     /* build CDP header */
@@ -157,4 +153,3 @@ bad:
     return (EXIT_FAILURE);
 }
 
-/* EOF */
