@@ -30,13 +30,7 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
 #include "./libnet_test.h"
-#ifdef __WIN32__
-#include "../include/win32/getopt.h"
-#endif
 
 int
 main(int argc, char *argv[])
@@ -109,4 +103,3 @@ main(int argc, char *argv[])
     exit(EXIT_SUCCESS);
 }
 
-/* EOF */
