@@ -69,7 +69,7 @@ main(int argc, char **argv)
         exit(EXIT_FAILURE);
     }
 
-    if (argc != 2 || ((target = libnet_name2addr4(l, argv[1], LIBNET_RESOLVE) == -1)))
+    if (argc != 2 || ((target = libnet_name2addr4(l, argv[1], LIBNET_RESOLVE)) == -1))
     {
         fprintf(stderr, "Usage: %s <target>\n", argv[0]);
         exit(EXIT_FAILURE);
@@ -158,7 +158,8 @@ main(int argc, char **argv)
     fprintf(stderr, "Packets sent:  %lld\n"
                     "Packet errors: %lld\n"
                     "Bytes written: %lld\n",
-                    ls.packets_sent, ls.packet_errors, ls.bytes_written);
+                    (long long)ls.packets_sent, (long long)ls.packet_errors,
+		    (long long)ls.bytes_written);
     libnet_destroy(l);
     free(data);
     return (EXIT_SUCCESS);
@@ -168,4 +169,3 @@ bad:
     return (EXIT_FAILURE);
 }
 
-/* EOF */
