@@ -30,14 +30,7 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 libnet_ptag_t
 libnet_build_802_1q(const uint8_t *dst, const uint8_t *src, uint16_t tpi, 
@@ -74,8 +67,7 @@ const uint8_t* payload, uint32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
             | (vlan_id & LIBNET_802_1Q_VIDMASK));
     _802_1q_hdr.vlan_len = htons(len_proto);
 
-    n = libnet_pblock_append(l, p, (uint8_t *)&_802_1q_hdr, LIBNET_802_1Q_H);
-    if (n == (uint32_t)-1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&_802_1q_hdr, LIBNET_802_1Q_H) == -1)
     {
         goto bad;
     }
@@ -98,5 +90,9 @@ bad:
     return (-1);
 }
 
-
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
