@@ -30,21 +30,14 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
-
+#include "common.h"
 
+/* FIXME this won't work with TCP or IPv4 data, which is probably a bug */
 libnet_ptag_t
-libnet_build_data(u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_build_data(const uint8_t *payload, uint32_t payload_s, libnet_t *l,
 libnet_ptag_t ptag)
 {
-    u_int32_t n, h;
+    uint32_t n, h;
     libnet_pblock_t *p;
 
     if (l == NULL)
@@ -74,4 +67,9 @@ bad:
     return (-1);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
