@@ -77,7 +77,7 @@ libnet_build_dnsv4(uint16_t h_len, uint16_t id, uint16_t flags,
      * anyway.
      */
     memset(&dns_hdr, 0, sizeof(dns_hdr));
-    dns_hdr.h_len       = htons((u_short)(n - sizeof (dns_hdr.h_len)));
+    dns_hdr.h_len       = htons((uint16_t)(n - sizeof (dns_hdr.h_len)));
     dns_hdr.id          = htons(id);
     dns_hdr.flags       = htons(flags);
     dns_hdr.num_q       = htons(num_q);
@@ -91,8 +91,7 @@ libnet_build_dnsv4(uint16_t h_len, uint16_t id, uint16_t flags,
      * but not in UDP packets. As they are the first 2 bytes of the header,
      * they are skipped if the packet is UDP...
      */
-    n = libnet_pblock_append(l, p, ((uint8_t *)&dns_hdr) + offset, h_len);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, ((uint8_t *)&dns_hdr) + offset, h_len) == -1)
     {
         goto bad;
     }
