@@ -29,22 +29,14 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 libnet_ptag_t
-libnet_build_hsrp(u_int8_t version, u_int8_t opcode, u_int8_t state, 
-u_int8_t hello_time, u_int8_t hold_time, u_int8_t priority, u_int8_t group,
-u_int8_t reserved, u_int8_t authdata[HSRP_AUTHDATA_LENGTH], u_int32_t virtual_ip,
-u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_hsrp(uint8_t version, uint8_t opcode, uint8_t state, 
+uint8_t hello_time, uint8_t hold_time, uint8_t priority, uint8_t group,
+uint8_t reserved, uint8_t authdata[HSRP_AUTHDATA_LENGTH], uint32_t virtual_ip,
+const uint8_t *payload, uint32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
-    u_int32_t n;
     libnet_pblock_t *p;
     struct libnet_hsrp_hdr hsrp_hdr;
 
@@ -57,7 +49,7 @@ u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
      *  Find the existing protocol block if a ptag is specified, or create
      *  a new one.
      */
-    p = libnet_pblock_probe(l, ptag, LIBNET_HSRP_H, LIBNET_PBLOCK_HSRP_H);
+    p = libnet_pblock_probe(l, ptag, LIBNET_HSRP_H + payload_s, LIBNET_PBLOCK_HSRP_H);
     if (p == NULL)
     {
         return (-1);
@@ -72,26 +64,24 @@ u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
     hsrp_hdr.priority = priority;
     hsrp_hdr.group = group;
     hsrp_hdr.reserved = reserved;
-    memcpy(hsrp_hdr.authdata, authdata, HSRP_AUTHDATA_LENGTH*sizeof(u_int8_t));
+    memcpy(hsrp_hdr.authdata, authdata, HSRP_AUTHDATA_LENGTH*sizeof(uint8_t));
     hsrp_hdr.virtual_ip = virtual_ip;
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&hsrp_hdr, LIBNET_HSRP_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&hsrp_hdr, LIBNET_HSRP_H) == -1)
     {
         goto bad;
     }
 
-    if ((payload && !payload_s) || (!payload && payload_s))
+    if (payload_s && !payload)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-                "%s(): payload inconsistency\n", __func__);
+                "%s(): payload inconsistency", __func__);
         goto bad;
     }
  
-    if (payload && payload_s)
+    if (payload_s)
     {
-        n = libnet_pblock_append(l, p, payload, payload_s);
-        if (n == -1)
+        if (libnet_pblock_append(l, p, payload, payload_s) == -1)
         {
             goto bad;
         }
@@ -102,4 +92,10 @@ bad:
     libnet_pblock_delete(l, p);
     return (-1);
 }
-/* EOF */
+
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
