@@ -30,20 +30,13 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 libnet_ptag_t
-libnet_build_igmp(u_int8_t type, u_int8_t code, u_int16_t sum, u_int32_t ip,
-u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_igmp(uint8_t type, uint8_t reserved, uint16_t sum, uint32_t ip,
+const uint8_t *payload, uint32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
-    u_int32_t n, h;
+    uint32_t n, h;
     libnet_pblock_t *p;
     struct libnet_igmp_hdr igmp_hdr;
 
@@ -66,13 +59,12 @@ u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
     }
 
     memset(&igmp_hdr, 0, sizeof(igmp_hdr));
-    igmp_hdr.igmp_type         = type;    /* packet type */
-    igmp_hdr.igmp_code         = code;    /* packet code */
-    igmp_hdr.igmp_sum          = (sum ? htons(sum) : 0);  /* packet checksum */
-    igmp_hdr.igmp_group.s_addr = htonl(ip);
+    igmp_hdr.igmp_type         = type;
+    igmp_hdr.igmp_code         = reserved;
+    igmp_hdr.igmp_sum          = (sum ? htons(sum) : 0);
+    igmp_hdr.igmp_group.s_addr = ip;
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&igmp_hdr, LIBNET_IGMP_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&igmp_hdr, LIBNET_IGMP_H) == -1)
     {
         goto bad;
     }
@@ -96,4 +88,9 @@ bad:
     return (-1);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
