@@ -31,21 +31,13 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
-
+#include "common.h"
 
 libnet_ptag_t
-libnet_build_ipsec_esp_hdr(u_int32_t spi, u_int32_t seq, u_int32_t iv,
-u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ipsec_esp_hdr(uint32_t spi, uint32_t seq, uint32_t iv,
+const uint8_t *payload, uint32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
-    u_int32_t n, h;
+    uint32_t n, h;
     libnet_pblock_t *p;
     struct libnet_esp_hdr esp_hdr;
 
@@ -72,8 +64,7 @@ u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
         return (-1);
     }
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&esp_hdr, LIBNET_IPSEC_ESP_HDR_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&esp_hdr, LIBNET_IPSEC_ESP_HDR_H) == -1)
     {
         goto bad;
     }
@@ -90,12 +81,12 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ipsec_esp_ftr(u_int8_t len, u_int8_t nh, int8_t *auth,
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_build_ipsec_esp_ftr(uint8_t len, uint8_t nh, int8_t *auth,
+            const uint8_t *payload, uint32_t payload_s, libnet_t *l,
             libnet_ptag_t ptag)
 {
     /* XXX we need to know the size of auth */
-    u_int32_t n, h;
+    uint32_t n, h;
     libnet_pblock_t *p;
     struct libnet_esp_ftr esp_ftr;
 
@@ -122,8 +113,8 @@ libnet_build_ipsec_esp_ftr(u_int8_t len, u_int8_t nh, int8_t *auth,
         return (-1);
     }
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&esp_ftr, LIBNET_IPSEC_ESP_FTR_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&esp_ftr,
+                             LIBNET_IPSEC_ESP_FTR_H) == -1)
     {
         goto bad;
     }
@@ -140,11 +131,11 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ipsec_ah(u_int8_t nh, u_int8_t len, u_int16_t res,
-u_int32_t spi, u_int32_t seq, u_int32_t auth, u_int8_t *payload,
-u_int32_t payload_s,  libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ipsec_ah(uint8_t nh, uint8_t len, uint16_t res,
+uint32_t spi, uint32_t seq, uint32_t auth, const uint8_t *payload,
+uint32_t payload_s,  libnet_t *l, libnet_ptag_t ptag)
 {
-    u_int32_t n, h;
+    uint32_t n, h;
     libnet_pblock_t *p;
     struct libnet_ah_hdr ah_hdr;
 
@@ -174,8 +165,7 @@ u_int32_t payload_s,  libnet_t *l, libnet_ptag_t ptag)
     ah_hdr.ah_seq = htonl(seq);        /* AH sequence number */
     ah_hdr.ah_auth = htonl(auth);      /* authentication data */
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&ah_hdr, LIBNET_IPSEC_AH_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&ah_hdr, LIBNET_IPSEC_AH_H) == -1)
     {
         goto bad;
     }
@@ -190,4 +180,9 @@ bad:
     return (-1);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
