@@ -30,22 +30,15 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 libnet_ptag_t
-libnet_build_isl(u_int8_t *dhost, u_int8_t type, u_int8_t user,
-u_int8_t *shost, u_int16_t len, u_int8_t *snap, u_int16_t vid,
-u_int16_t portindex, u_int16_t reserved, u_int8_t *payload,
-u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_isl(uint8_t *dhost, uint8_t type, uint8_t user,
+uint8_t *shost, uint16_t len, const uint8_t *snap, uint16_t vid,
+uint16_t portindex, uint16_t reserved, const uint8_t *payload,
+uint32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
-    u_int32_t n, h;
+    uint32_t n;
     libnet_pblock_t *p;
     struct libnet_isl_hdr isl_hdr;
 
@@ -55,7 +48,6 @@ u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
     }
 
     n = LIBNET_ISL_H + payload_s;           /* size of memory block */
-    h = 0;
 
     /*
      *  Find the existing protocol block if a ptag is specified, or create
@@ -68,18 +60,17 @@ u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
     }
 
     memset(&isl_hdr, 0, sizeof (isl_hdr));
-    memcpy(&isl_hdr.isl_dhost, dhost, 5);
+    memcpy(&isl_hdr.isl_dhost, dhost, sizeof(isl_hdr.isl_dhost));
     isl_hdr.isl_type    = type;
     isl_hdr.isl_user    = user;
-    memcpy(&isl_hdr.isl_shost, shost, 6);
+    memcpy(&isl_hdr.isl_shost, shost, sizeof(isl_hdr.isl_shost));
     isl_hdr.isl_len     = htons(len);
-    memcpy(&isl_hdr.isl_dhost, snap, 6);
+    memcpy(&isl_hdr.isl_snap, snap, sizeof(isl_hdr.isl_snap));
     isl_hdr.isl_vid     = htons(vid);
     isl_hdr.isl_index   = htons(portindex);
     isl_hdr.isl_reserved= htons(reserved);
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&isl_hdr, LIBNET_ISL_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&isl_hdr, LIBNET_ISL_H) == -1)
     {
         goto bad;
     }
@@ -96,4 +87,9 @@ bad:
     return (-1);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
