@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_snmp.c,v 1.1.1.1 2000/05/25 00:28:49 route Exp $
+ *  $Id: libnet_build_snmp.c,v 1.4 2004/01/03 20:31:01 mike Exp $
  *
  *  libnet
  *  libnet_build_snmp.c - SNMP packet assembler
  *
- *  Copyright (c) 1998 - 2001 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -30,13 +30,10 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#include "../include/libnet.h"
+#include "common.h"
 
-int
-libnet_build_snmp()
+libnet_ptag_t
+libnet_build_snmp(void)
 {
     /*
      *  We need an ASN.1 BER encoder before we can write this.
@@ -44,5 +41,9 @@ libnet_build_snmp()
     return (-1);
 }
 
-
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
