@@ -30,30 +30,23 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 libnet_ptag_t
-libnet_build_stp_conf(u_int16_t id, u_int8_t version, u_int8_t bpdu_type,
-u_int8_t flags, u_int8_t *root_id, u_int32_t root_pc, u_int8_t *bridge_id,
-u_int16_t port_id, u_int16_t message_age, u_int16_t max_age,
-u_int16_t hello_time, u_int16_t f_delay, u_int8_t *payload,
-u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_stp_conf(uint16_t id, uint8_t version, uint8_t bpdu_type,
+uint8_t flags, const uint8_t *root_id, uint32_t root_pc, const uint8_t *bridge_id,
+uint16_t port_id, uint16_t message_age, uint16_t max_age,
+uint16_t hello_time, uint16_t f_delay, const uint8_t *payload,
+uint32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
-    u_int32_t n, h;
+    uint32_t n, h;
     libnet_pblock_t *p;
 
     /* until we get some data marshalling in place we can't use this */
     /* struct libnet_stp_conf_hdr stp_hdr; */
-    u_int8_t stp_hdr[35];
-    u_int16_t value_s;
-    u_int32_t value_l;
+    uint8_t stp_hdr[35];
+    uint16_t value_s;
+    uint32_t value_l;
 
     if (l == NULL)
     { 
@@ -127,9 +120,8 @@ u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 
 
     /* until we get some data marshalling in place we can't use this */
-    /*n = libnet_pblock_append(l, p, (u_int8_t *)&stp_hdr, LIBNET_STP_CONF_H); */
-    n = libnet_pblock_append(l, p, stp_hdr, LIBNET_STP_CONF_H);
-    if (n == -1)
+    /*n = libnet_pblock_append(l, p, (uint8_t *)&stp_hdr, LIBNET_STP_CONF_H); */
+    if (libnet_pblock_append(l, p, stp_hdr, LIBNET_STP_CONF_H) == -1)
     {
         goto bad;
     }
@@ -146,10 +138,10 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_stp_tcn(u_int16_t id, u_int8_t version, u_int8_t bpdu_type,
-u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_stp_tcn(uint16_t id, uint8_t version, uint8_t bpdu_type,
+const uint8_t *payload, uint32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
-    u_int32_t n, h;
+    uint32_t n, h;
     libnet_pblock_t *p;
 
     struct libnet_stp_tcn_hdr stp_hdr;
@@ -177,8 +169,7 @@ u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
     stp_hdr.stp_version   = version;
     stp_hdr.stp_bpdu_type = bpdu_type;
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&stp_hdr, LIBNET_STP_TCN_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&stp_hdr, LIBNET_STP_TCN_H) == -1)
     {
         goto bad;
     }
@@ -193,4 +184,9 @@ bad:
     return (-1);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
