@@ -30,14 +30,7 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 libnet_ptag_t
 libnet_build_vrrp(uint8_t version, uint8_t type, uint8_t vrouter_id, 
@@ -77,8 +70,7 @@ libnet_ptag_t ptag)
     vrrp_hdr.vrrp_advert_int = advert_int;
     vrrp_hdr.vrrp_sum        = (sum ? htons(sum) : 0);
 
-    n = libnet_pblock_append(l, p, (uint8_t *)&vrrp_hdr, LIBNET_VRRP_H);
-    if (n == -1)
+    if (libnet_pblock_append(l, p, (uint8_t *)&vrrp_hdr, LIBNET_VRRP_H) == -1)
     {
         goto bad;
     }
@@ -101,4 +93,9 @@ bad:
     return (-1);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
