@@ -30,14 +30,7 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 void
 libnet_diag_dump_hex(const uint8_t *packet, uint32_t len, int swap, FILE *stream)
@@ -109,8 +102,8 @@ libnet_diag_dump_context(libnet_t *l)
             break;
     }
     
-    fprintf(stderr, "pblock start:\t%p\n", l->protocol_blocks);
-    fprintf(stderr, "pblock end:\t%p\n", l->pblock_end);
+    fprintf(stderr, "pblock start:\t%p\n", (void*)l->protocol_blocks);
+    fprintf(stderr, "pblock end:\t%p\n", (void*)l->pblock_end);
     fprintf(stderr, "link type:\t%d\n", l->link_type);
     fprintf(stderr, "link offset:\t%d\n", l->link_offset);
     fprintf(stderr, "aligner:\t%d\n", l->aligner);
@@ -135,15 +128,15 @@ libnet_diag_dump_pblock(libnet_t *l)
         fprintf(stderr, "pblock type:\t%s\n", 
                 libnet_diag_dump_pblock_type(p->type));
         fprintf(stderr, "ptag number:\t%d\n", p->ptag);
-        fprintf(stderr, "pblock address:\t%p\n", p);
-        fprintf(stderr, "next pblock\t%p ", p->next);
+        fprintf(stderr, "pblock address:\t%p\n", (void*)p);
+        fprintf(stderr, "next pblock\t%p ", (void*)p->next);
         if (p->next)
         {
             fprintf(stderr, "(%s)",
                     libnet_diag_dump_pblock_type(p->next->type));
         }
         fprintf(stderr, "\n");
-        fprintf(stderr, "prev pblock\t%p ", p->prev);
+        fprintf(stderr, "prev pblock\t%p ", (void*)p->prev);
         if (p->prev)
         {
             fprintf(stderr, "(%s)",
@@ -305,6 +298,8 @@ libnet_diag_dump_pblock_type(uint8_t type)
             return ("hsrp");
         case LIBNET_PBLOCK_ICMPV6_H:
             return ("icmpv6");
+        case LIBNET_PBLOCK_ICMPV6_ECHO_H:
+            return ("icmpv6_echo");
         case LIBNET_PBLOCK_ICMPV6_UNREACH_H:
             return ("icmpv6_unreach");
         case LIBNET_PBLOCK_ICMPV6_NDP_NSOL_H:
@@ -313,7 +308,41 @@ libnet_diag_dump_pblock_type(uint8_t type)
             return ("icmpv6_ndp_nadv");
         case LIBNET_PBLOCK_ICMPV6_NDP_OPT_H:
             return ("icmpv6_ndp_opt");
+        case LIBNET_PBLOCK_LLDP_H:
+            return ("lldp");
+        case LIBNET_PBLOCK_LLDP_CHASSIS_H:
+            return ("lldp_chassis_id");
+        case LIBNET_PBLOCK_LLDP_PORT_H:
+            return ("lldp_port_id");
+        case LIBNET_PBLOCK_LLDP_TTL_H:
+            return ("lldp_ttl");
+        case LIBNET_PBLOCK_LLDP_END_H:
+            return ("lldp_end_lldpdu");
+        case LIBNET_PBLOCK_LLDP_ORG_SPEC_H:
+            return ("lldp_org_specific");
+        case LIBNET_PBLOCK_UDLD_H:
+            return ("udld");
+        case LIBNET_PBLOCK_UDLD_DEVICE_ID_H:
+            return ("udld_device_id");
+        case LIBNET_PBLOCK_UDLD_PORT_ID_H:
+            return ("udld_port_id");
+        case LIBNET_PBLOCK_UDLD_ECHO_H:
+            return ("udld_echo");
+        case LIBNET_PBLOCK_UDLD_MSG_INTERVAL_H:
+            return ("udld_message_interval");
+        case LIBNET_PBLOCK_UDLD_TMT_INTERVAL_H:
+            return ("udld_timeout_interval");
+        case LIBNET_PBLOCK_UDLD_DEVICE_NAME_H:
+            return ("udld_device_name");
+        case LIBNET_PBLOCK_UDLD_SEQ_NUMBER_H:
+            return ("udld_sequence_number");
     }
     return ("unrecognized pblock");
 }
 
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
