@@ -2,7 +2,7 @@
  *  $Id: libnet_version.c,v 1.7 2004/11/09 07:05:07 mike Exp $
  *
  *  libnet
- *  libnet_version.c - dummy version function to define version info
+ *  libnet_version.c - version function to return version info
  *
  *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
@@ -30,31 +30,9 @@
  *
  */
 
-#if (!(_WIN32) || (__CYGWIN__))
-#include <unistd.h>
-#include "../version.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
-#ifndef STDOUT_FILENO
-#define STDOUT_FILENO 1
-#endif
-
-static const char banner[] = "libnet version "VERSION"";
-
-void
-__libnet_print_vers(void)
-{
-    /*
-     *  We don't check for error cos we really don't care.
-     */
-#if defined (__WIN32__)
-     fprintf(stdout, "%s", banner);
-#else
-     (void)write(STDOUT_FILENO, banner, sizeof(banner) - 1);
-#endif
-}
+static const char banner[] = "libnet version " LIBNET_VERSION "";
 
 const char *
 libnet_version(void)
@@ -62,4 +40,9 @@ libnet_version(void)
     return (banner);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
